==> libunistring_1.0.orig.tar.xz: libunistring-1.0/lib/unistr/u8-set.c <==
/* Fill UTF-8 string.
   Copyright (C) 2002, 2006, 2009-2022 Free Software Foundation, Inc.
   Written by Bruno Haible <bruno@clisp.org>, 2002.

   This file is free software.
   It is dual-licensed under "the GNU LGPLv3+ or the GNU GPLv2+".
   You can redistribute it and/or modify it under either
     - the terms of the GNU Lesser General Public License as published
       by the Free Software Foundation; either version 3, or (at your
       option) any later version, or
     - the terms of the GNU General Public License as published by the
       Free Software Foundation; either version 2, or (at your option)
       any later version, or
     - the same dual license "the GNU LGPLv3+ or the GNU GPLv2+".

   This file is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License and the GNU General Public License
   for more details.

   You should have received a copy of the GNU Lesser General Public
   License and of the GNU General Public License along with this
   program.  If not, see <https://www.gnu.org/licenses/>.  */

#include <config.h>

/* Specification.  */
#include "unistr.h"

#define FUNC u8_set
#define UNIT uint8_t
#define IS_SINGLE_UNIT(uc) (uc < 0x80)

#include <errno.h>
#include <string.h>

UNIT *
FUNC (UNIT *s, ucs4_t uc, size_t n)
{
  if (n > 0)
    {
      if (IS_SINGLE_UNIT (uc))
        memset ((char *) s, uc, n);
      else
        {
          errno = EILSEQ;
          return NULL;
        }
    }
  return s;
}

==> libunistring_1.3.orig.tar.xz: libunistring-1.3/lib/unistr/u8-set.c <==
/* Fill UTF-8 string.
   Copyright (C) 2002, 2006, 2009-2024 Free Software Foundation, Inc.
   Written by Bruno Haible <bruno@clisp.org>, 2002.

   This file is free software.
   It is dual-licensed under "the GNU LGPLv3+ or the GNU GPLv2+".
   You can redistribute it and/or modify it under either
     - the terms of the GNU Lesser General Public License as published
       by the Free Software Foundation, either version 3, or (at your
       option) any later version, or
     - the terms of the GNU General Public License as published by the
       Free Software Foundation; either version 2, or (at your option)
       any later version, or
     - the same dual license "the GNU LGPLv3+ or the GNU GPLv2+".

   This file is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License and the GNU General Public License
   for more details.

   You should have received a copy of the GNU Lesser General Public
   License and of the GNU General Public License along with this
   program.  If not, see <https://www.gnu.org/licenses/>.  */

#include <config.h>

/* Specification.  */
#include "unistr.h"

#define FUNC u8_set
#define UNIT uint8_t
#define IS_SINGLE_UNIT(uc) (uc < 0x80)

#include <errno.h>
#include <string.h>

UNIT *
FUNC (UNIT *s, ucs4_t uc, size_t n)
{
  if (n > 0)
    {
      if (IS_SINGLE_UNIT (uc))
        memset ((char *) s, uc, n);
      else
        {
          errno = EILSEQ;
          return NULL;
        }
    }
  return s;
}
